'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var fs = require('fs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var path__default = /*#__PURE__*/_interopDefaultLegacy(path);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);

function pressUiResolveVitePlugin(options) {
    const root = options?.root ?? process.cwd();
    return {
        name: 'vite-plugin-press-ui-resolve',
        resolveId(id) {
            const vueReg = /@tencent\/press-ui\/(.*)\.vue$/;
            const target = tryMJSFile({
                reg: vueReg,
                id,
                root,
                tryMjs: true,
            });
            if (target && fs__default["default"].existsSync(target)) {
                return target;
            }
            const scssReg = /@tencent\/press-ui\/(.*)\.scss$/;
            const scssTarget = tryMJSFile({
                reg: scssReg,
                id,
                root,
                tryCss: true,
            });
            if (scssTarget && fs__default["default"].existsSync(scssTarget)) {
                return scssTarget;
            }
            const normalReg = /@tencent\/press-ui\/(.*)$/;
            const normalTarget = tryMJSFile({
                reg: normalReg,
                id,
                root,
                tryMjs: true,
                tryCss: true,
                tryPure: true,
            });
            if (normalTarget && fs__default["default"].existsSync(normalTarget)) {
                return normalTarget;
            }
            return null;
        },
    };
}
function tryMJSFile({ reg, id, root, tryCss = false, tryMjs = false, tryPure = false, }) {
    const normalMatch = id.match(reg);
    const normalFile = normalMatch?.[1];
    const pureTarget = path__default["default"].resolve(root, `node_modules/press-ui-next/${normalFile}`);
    const normalTarget = path__default["default"].resolve(root, `node_modules/press-ui-next/${normalFile}.mjs`);
    const cssTarget = path__default["default"].resolve(root, `node_modules/press-ui-next/${normalFile}.css`);
    if (tryPure && fs__default["default"].existsSync(pureTarget)) {
        console.log(`[pressUiResolveVitePlugin] handled pure ${id}`);
        return pureTarget;
    }
    if (tryMjs && fs__default["default"].existsSync(normalTarget)) {
        console.log(`[pressUiResolveVitePlugin] handled mjs ${id}`);
        return normalTarget;
    }
    if (tryCss && fs__default["default"].existsSync(cssTarget)) {
        console.log(`[pressUiResolveVitePlugin] handled css ${id}`);
        return cssTarget;
    }
}

exports.pressUiResolveVitePlugin = pressUiResolveVitePlugin;
